Re: Site doesn't render - just HTML code

Jorge Arellano Cid <[email protected]>
Newsgroups gmane.comp.web.dillo.devel
Message-ID <[email protected]>
On Fri, Sep 16, 2016 at 07:31:45PM +0100, Nick Warne wrote:
> 
> Only me again :)
> 
> Firefox, links and lynx render this page OK, but Dillo just shows the
> HTML code:
> 
> http://www.afrowsoft.co.uk
> 
> ?

  I gave it a quick look with no luck. After a second review the
problem showed up. Please try the attached patch.

  It happened to me in the past, and as the comments for doxygen
show, there may be more cases.

  If somebody else has experienced this, please try the patch and
send feedback.


-- 
  Cheers
  Jorge.-

_______________________________________________
Dillo-dev mailing list
[email protected]
http://lists.dillo.org/cgi-bin/mailman/listinfo/dillo-dev
meta.diff (text/x-diff, 867 B)
diff -r 51dcebebbaa6 src/cache.c
--- a/src/cache.c	Wed Aug 10 13:00:43 2016 -0400
+++ b/src/cache.c	Wed Sep 21 12:11:52 2016 -0300
@@ -518,8 +518,10 @@ const char *a_Cache_set_content_type(con
             /* META only gives charset; use detected MIME type too */
             entry->TypeNorm = dStrconcat(entry->TypeDet, ctype, NULL);
          } else if (*from == 'm' &&
-                    !dStrnAsciiCasecmp(ctype, "text/xhtml", 10)) {
-            /* WORKAROUND: doxygen uses "text/xhtml" in META */
+                    (!dStrnAsciiCasecmp(ctype, "text/xhtml", 10) ||
+                     !dStrnAsciiCasecmp(ctype, "text/xml", 8))) {
+            /* WORKAROUNDS: doxygen uses "text/xhtml" in META,
+             * others use "text/xml" (e.g. www.afrowsoft.co.uk) */
             entry->TypeNorm = dStrdup(entry->TypeDet);
          }
          if (charset) {
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.